"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.deployFunction = exports.generateFunctionName = exports.RouteType = exports.readLambdaConfig = void 0;
const utils_aws_cli_1 = require("@goldstack/utils-aws-cli");
const utils_sh_1 = require("@goldstack/utils-sh");
var collectLambdasFromFiles_1 = require("./generate/collectLambdasFromFiles");
Object.defineProperty(exports, "readLambdaConfig", { enumerable: true, get: function () { return collectLambdasFromFiles_1.readLambdaConfig; } });
Object.defineProperty(exports, "RouteType", { enumerable: true, get: function () { return collectLambdasFromFiles_1.RouteType; } });
var generateFunctionName_1 = require("./generate/generateFunctionName");
Object.defineProperty(exports, "generateFunctionName", { enumerable: true, get: function () { return generateFunctionName_1.generateFunctionName; } });
const deployFunction = async (params) => {
    const targetArchive = params.targetArchiveName || `lambda-${new Date().getTime()}.zip`;
    await (0, utils_sh_1.rmSafe)(targetArchive);
    await (0, utils_sh_1.zip)({
        directory: params.lambdaPackageDir,
        target: targetArchive,
        mode: 511,
    });
    let fixedTargetArchive = targetArchive;
    const isWin = process.platform === 'win32';
    if (!isWin) {
        fixedTargetArchive = fixedTargetArchive.replace(/\$/g, '\\$');
    }
    const deployResult = await (0, utils_aws_cli_1.awsCli)({
        credentials: params.awsCredentials,
        region: params.region,
        options: {
            silent: true,
        },
        command: `lambda update-function-code --function-name ${params.functionName} --zip-file fileb://${fixedTargetArchive}`,
    });
    if (!params.targetArchiveName) {
        await (0, utils_sh_1.rmSafe)(targetArchive);
    }
    // wait until lambda becomes active
    let counter = 0;
    let state = '';
    while (counter < 20 && state !== 'Active') {
        const res = await (0, utils_aws_cli_1.awsCli)({
            credentials: params.awsCredentials,
            region: params.region,
            options: {
                silent: true,
            },
            command: `lambda get-function --function-name ${params.functionName}`,
        });
        const data = JSON.parse(res);
        state = data.Configuration.State;
        counter++;
    }
    if (counter >= 20) {
        throw new Error(`Function was still in state '${state}' after deployment`);
    }
    return JSON.parse(deployResult);
};
exports.deployFunction = deployFunction;
//# sourceMappingURL=utilsAwsLambda.js.map